function x = fun1( t,dx,u)

%% Physical parameter
mini.p1   = 0.0275;     % Insulin independent glucose romoval [1/min]
mini.p2   = 0.035;      % Remote insulin activity removal rate [1/min]
mini.p3   = 0.000046;   % Insulin action sensitivity param [l/mU/min/min]
mini.n    = 0.142;      % Plasma insulin decay parameter [1/min]
mini.Vp   = 117.0;      % Plasma volume, dL
mini.Vi   = 11.0;       % Insulin distribution volume [L]
mini.Gb   = 81.0;       % Basic glucose level [mg/dL]
mini.Ib   = 10.0;       % Basic glucose level [mg/dL]
mini.Td   = 10.0;       % Insulin time delay [min]
mini.Rm   = 80;         % Maximum own insulin release [mU/min] (Start=300)
mini.C1   = 120.0;      % Insulin release parameter [mg/dL]
mini.a1   = 10.0;       % Own insulin release parameter [mg/dL]
mini.Xs   = 0.0;
mini.nPot = 4;
mini.aHR  = (1/0.049)^4;
mini.Tex  = 600.0;
% mini.alfa = 1.116;
% mini.beta = 0.0256;

mini.alfa = 0.974;
mini.beta = 0.000339;

% Steady state insulin input (simulates slow insulin)
mini.Ub  = mini.n*mini.Vi*mini.Ib;
mini.Ss  = mini.Ub*mini.Td;

%% Stomach/gut parameters
mini.kabs = 0.06;
mini.kemp = 0.03;                                              
mini.f    = 0.9;

u_meal=u(1);
u_ins=u(2);
Y=u(3);


Ra   = mini.f*mini.kabs*dx(6);  
%Y    = dArr(i,2);
fY   = mini.aHR*Y^mini.nPot/(1+mini.aHR*Y^mini.nPot);
hlp     = 1+exp((mini.C1-dx(1))/mini.a1);
iOwn    = mini.Rm/hlp;
Iact = (dx(4)/mini.Td+iOwn)/(mini.n*mini.Vi);


x(1) = -(mini.p1+(1.0+mini.alfa*dx(7))*dx(2))*dx(1)- ...
             mini.beta*Y*dx(1)+mini.p1*mini.Gb+Ra/mini.Vp;
x(2) = -mini.p2*dx(2)+mini.p3*(Iact-mini.Ib);
x(3) = u_ins+mini.Ub-dx(3)/mini.Td;
x(4) = (dx(3)-dx(4))/mini.Td;
x(5) = -mini.kemp*dx(5)+u_meal;
x(6) = -mini.kabs*dx(6)+mini.kemp*dx(5);
x(7) = -(fY+1.0/mini.Tex)*dx(7)+fY;


x=[x(1); x(2); x(3); x(4); x(5); x(6); x(7)];

end



