% Initialization program for glucose metabolig estimation
clear all;
load T1mat;
load BG;
B0=[1.49e-05 5.47e-05 1.85e-04 2.34e-04 3.38e-04 1.289058e-3 ...
    0.002162215	0.004276446	0.005639424	0.001735444];

C0 = 5.287719298;

timeHor = 900;               % Simulation time in minutes
dT      = 1;               % Simulation sampling time in minutes
time    = 0:dT:timeHor;     % Time array
nSim    = length(time);      % Number of simulation steps

%% Meal(s) structure
dArr  = zeros(nSim,2);      % Meal array
uArr  = zeros(nSim,1);      % Insulin array

MeasT   = BG(:,2)';
mTime1   = 1440*(BG(:,1)'-BG(1,1));  % Defines starttime
mTime=round(mTime1);
NIRtime = 1440*(NIRtime-BG(1,1));
dArr(50,1)   = 39100/dT;
dArr(472,1)  = 39100/dT;
dArr(1130,1) = 63100/dT;
dArr(1140:1292,2) = 1.45;
    
%% Physical parameter
mini.p1  = 0.0275;     % Insulin independent glucose romoval [1/min]
mini.p2  = 0.035;      % Remote insulin activity removal rate [1/min]
mini.p3  = 0.000046;   % Insulin action sensitivity param [l/mU/min/min]
mini.n   = 0.142;      % Plasma insulin decay parameter [1/min]
mini.Vp  = 117.0;      % Plasma volume, dL
mini.Vi  = 11.0;       % Insulin distribution volume [L]
mini.Gb  = 81.0;       % Basic glucose level [mg/dL]
mini.Gs  = 81.0;       % Basic glucose level [mg/dL]
mini.Ib  = 10.0;       % Basic glucose level [mg/dL]
mini.Td  = 10.0;       % Insulin time delay [min]
mini.Rm  = 100;        % Maximum own insulin release [mU/min] (Start=300)
mini.C1  = 140.0;      % Insulin release parameter [mg/dL]
mini.a1  = 10.0;       % Own insulin release parameter [mg/dL]
mini.Xs  = 0.0;
mini.nPot = 4;
mini.aHR  = 0.049;
mini.Tex  = 600.0;
mini.alfa = 1.116;
mini.beta = 0.0256;

% Steady state insulin input (simulates slow insulin)
mini.Ub  = mini.n*mini.Vi*mini.Ib;
mini.Sss = mini.Ub*mini.Td;

%% Stomach/gut parameters
mini.kabs = 0.057;  %0.057
mini.kemp = 0.020;  %0.02
mini.f    = 0.9;
    
%% ==================  OPTIMIZE    ====================
    Lb = [0.005,0.1,0.005]; 
    Ub = [0.2,5,0.1,];
    x  = [mini.aHR,mini.alfa,mini.beta];
%   options = optimset('MaxFunEvals',1000);
%   [x,fval,exitflag,output,grad,hessian]  = ...
%        fmincon(@(x) gOptModNewTerje(x,MeasT,mTime,time,NIRtime,dT,dArr,uArr,mini,NirEst1, ...
%        Scores1,B0,C0,Rsd1),x,[],[],[],[],Lb,Ub,[], options);
%% ====================================================

mini.aHR   = x(1);
mini.alfa  = x(2);
mini.beta  = x(3);
%kalman array er knArr

[obj,xArr,eArr,kArr,knArr, fiArr,pArr,uArr, r] = ...
    makeKalman(time,dT,MeasT,mTime,NIRtime,dArr,uArr,mini,2,NirEst1,Scores1,...
    B0,C0,Rsd1);
r
plotOSim(xArr,pArr,time,mTime,MeasT,pArr,mini);

