% Initialization program for glucose metabolig estimation
clear all;

timeHor = 310;              % Simulation time in minutes
dT      = 0.5;              % Simulation sampling time in minutes
time    = 1:dT:timeHor;     % Time array
nSim    = length(time);     % Number of simulation steps

%% Meal(s) structure and insulin dosage
dArr  = zeros(nSim,2);      % Meal array in simulator
dArrE = zeros(nSim,2);      % Meal array in estimator
uArr  = zeros(nSim,1);      % Insulin array

mTime        = 1:10:timeHor;
dM           = size(mTime);
nM           = dM(2);
    
%% Physical parameter
mini.p1   = 0.0275;     % Insulin independent glucose romoval [1/min]
mini.p2   = 0.035;      % Remote insulin activity removal rate [1/min]
mini.p3   = 0.000046;   % Insulin action sensitivity param [l/mU/min/min]
mini.n    = 0.142;      % Plasma insulin decay parameter [1/min]
mini.Vp   = 117.0;      % Plasma volume, dL
mini.Vi   = 11.0;       % Insulin distribution volume [L]
mini.Gb   = 81.0;       % Basic glucose level [mg/dL]
mini.Ib   = 10.0;       % Basic glucose level [mg/dL]
mini.Td   = 10.0;       % Insulin time delay [min]
mini.Rm   = 80;         % Maximum own insulin release [mU/min] (Start=300)
mini.C1   = 120.0;      % Insulin release parameter [mg/dL]
mini.a1   = 10.0;       % Own insulin release parameter [mg/dL]
mini.Xs   = 0.0;
mini.nPot = 4;
mini.aHR  = (1/0.049)^4;
mini.Tex  = 600.0;
% mini.alfa = 1.116;
% mini.beta = 0.0256;
mini.alfa = 0.974;
mini.beta = 0.000339;

% Steady state insulin input (simulates slow insulin)
mini.Ub  = mini.n*mini.Vi*mini.Ib;
mini.Ss  = mini.Ub*mini.Td;

%% Stomach/gut parameters
mini.kabs = 0.06;
mini.kemp = 0.03;                                           
mini.f    = 0.9;

[sArr,cE,Fish,xArr,eArr,kArr,fiArr,pArr,XHArr,XMArr] = senseMod(time,dT,mTime,dArr,uArr,mini);

plotSense(xArr,pArr,time,mTime,sArr,mini);

covMat=covariance_matrix(Fish);

detCovMat=det(covMat)
